library(jrvFinance)
library(cvar)
library(sn)

trials<-10000
IR = 0.03
i = rep(0.03,trials)

#find investment sum
set.seed(123)
CostOfLaunch = runif(trials, min = 1, max = 6)*11.3
CostofProduce = replicate(trials,51)
I = CostOfLaunch+CostofProduce

#generate revenue per year for 10 years
set.seed(123)
R = replicate(10,runif(trials, min = 780.1670, max = 1215.2893))

#generate other_expense per year for 10 year
set.seed(123)
E_0 = replicate(10,runif(trials, min = 477.8237, max = 867.8147))

#Revenue - Other_Expense
Net = R - E_0

#calculate Present Value of Net
PV_Net = replicate(10,rep(NA,trials))
for(i in 1:trials){
  for(j in 1:10){
    PV_Net[i,j]=Net[i,j]/((1+IR)^j)
  }
}

accumPV_Net <- rep(NA,trials)
for(i in 1:trials){
  accumPV_Net[i]=0
  for(j in 1:10){
    accumPV_Net[i]=accumPV_Net[i]+PV_Net[i,j]
  }
}

#########################Scenario  p = 0.3#######################
#generate loss at yr10: normal distribution -- mean = 99+51=105, sd = sqrt(105*p)
set.seed(123)
L1 = rnorm(n=trials, mean = 105, sqrt(105*0.3))
#generate the occurrence of loss
loss_1 <- rep(NA,trials)
set.seed(123)
occur_1 = rsn(n=trials, xi = 0, omega = 1, alpha = 30)
x1=mean(occur_1)
for(i in 1:trials){
if(occur_1[i]>=x1){loss_1[i]=L1[i]}
  else{loss_1[i]=0}
}
#Present Value of loss
PV_loss1 = rep(NA,trials)
for(i in 1:trials){
    PV_loss1[i]=loss_1[i]/((1+IR)^10)
  }


#calculate NPV
NPV1 <- rep(NA,trials)
for(i in 1:trials){
  NPV1[i] <- -I[i] + accumPV_Net[i] - PV_loss1[i]
}

mean(NPV1)
sd(NPV1)
hist(NPV1)
boxplot(NPV1)

#calculate IRR
for(i in 1:trials){
IRR1=irr(cf=c(-I[i],Net[i,1],Net[i,2],Net[i,3],Net[i,4],Net[i,5],Net[i,6],Net[i,7],Net[i,8],Net[i,9],Net[i,10]-loss_1[i]),cf.freq=1)
}
IRR1

#calculate VaR
ValueAtRisk1 = VaR(NPV1,p=0.95,method= c("historical"))
ValueAtRisk1

#########################Scenario  p = 0.5#######################
#generate loss at yr10: normal distribution -- mean = 99+51=105, sd = sqrt(105*p)
set.seed(123)
L2 = rnorm(n=trials, mean = 105, sqrt(105*0.5))
#generate the occurrence of loss
loss_2 <- rep(NA,trials)
for(i in 1:trials){
  if(occur_1[i]>=x1){loss_2[i]=L2[i]}
  else{loss_2[i]=0}
}
#Present Value of loss
PV_loss2 = rep(NA,trials)
for(i in 1:trials){
  PV_loss2[i]=loss_2[i]/((1+IR)^10)
}

#calculate NPV
NPV2 = rep(NA,trials)
for(i in 1:trials){
  NPV2[i] = -I[i] + accumPV_Net[i] - PV_loss2[i]
}

mean(NPV2)
sd(NPV2)
hist(NPV2)
boxplot(NPV2)

#calculate IRR
for(i in 1:trials){
  IRR2=irr(cf=c(-I[i],Net[i,1],Net[i,2],Net[i,3],Net[i,4],Net[i,5],Net[i,6],Net[i,7],Net[i,8],Net[i,9],Net[i,10]-loss_2[i]),cf.freq=1)
}
IRR2

#calculate VaR
ValueAtRisk2 = VaR(NPV2,p=0.95,method= c("historical"))
ValueAtRisk2

#########################Scenario  p = 0.7#######################
#generate loss at yr10: normal distribution -- mean = 99+51=105, sd = sqrt(105*p)
set.seed(123)
L3 = rnorm(n=trials, mean = 105, sqrt(105*0.7))
#generate the occurrence of loss
loss_3 <- rep(NA,trials)
for(i in 1:trials){
  if(occur_1[i]>=x1){loss_3[i]=L3[i]}
  else{loss_3[i]=0}
}
#Present Value of loss
PV_loss3 = rep(NA,trials)
for(i in 1:trials){
  PV_loss3[i]=loss_3[i]/((1+IR)^10)
}

#calculate NPV
NPV3 = rep(NA,trials)
for(i in 1:trials){
  NPV3[i] = -I[i] + accumPV_Net[i] - PV_loss3[i]
}

mean(NPV3)
sd(NPV3)
hist(NPV3)
boxplot(NPV3)

#calculate IRR
for(i in 1:trials){
  IRR3=irr(cf=c(-I[i],Net[i,1],Net[i,2],Net[i,3],Net[i,4],Net[i,5],Net[i,6],Net[i,7],Net[i,8],Net[i,9],Net[i,10]-loss_3[i]),cf.freq=1)
}
IRR3

#calculate VaR
ValueAtRisk3 = VaR(NPV3,p=0.95,method= c("historical"))
ValueAtRisk3

data=data.frame(I,accumPV_Net,loss_1,loss_2,loss_3,i,NPV1,NPV2,NPV3)

result=data.frame(matrix(data=c(mean(NPV1),sd(NPV1),IRR1,ValueAtRisk1,mean(NPV2),sd(NPV2),IRR2,ValueAtRisk2,mean(NPV3),sd(NPV3),IRR3,ValueAtRisk3),nrow=3,byrow = T))
result




