library(jrvFinance)
library(cvar)
library(sn)

trials<-10000
IR = 0.03
i = rep(0.03,trials)

#find investment sum
set.seed(123)
CostOfLaunch = replicate(trials,1*11.3) #initial sum is constant: 1, 2, 3, 4, 5, 6
CostofProduce = replicate(trials,51)
I = CostOfLaunch+CostofProduce

#generate revenue per year for 10 years
set.seed(123)
R = replicate(10,runif(trials, min = 780.1670, max = 1215.2893))

#generate other_expense per year for 10 year
set.seed(123)
E_0 = replicate(10,runif(trials, min = 477.8237, max = 867.8147))

#Revenue - Other_Expense
Net = R - E_0

#calculate Present Value of Net
PV_Net = replicate(10,rep(NA,trials))
for(i in 1:trials){
  for(j in 1:10){
    PV_Net[i,j]=Net[i,j]/((1+IR)^j)
  }
}

accumPV_Net <- rep(NA,trials)
for(i in 1:trials){
  accumPV_Net[i]=0
  for(j in 1:10){
    accumPV_Net[i]=accumPV_Net[i]+PV_Net[i,j]
  }
}

#########################Scenario  p = 0.3#######################
#generate loss at yr10: normal distribution -- mean = 99+51=105, sd = sqrt(105*p)
set.seed(123)
L = rnorm(n=trials, mean = 105, sqrt(105*0.3))
#generate the occurrence of loss
loss <- rep(NA,trials)
set.seed(123)
occur = rsn(n=trials, xi = 0, omega = 1, alpha = 30)
x1=mean(occur)
for(i in 1:trials){
  if(occur[i]>=x1){loss[i]=L[i]}
  else{loss[i]=0}
}
#Present Value of loss
PV_loss = rep(NA,trials)
for(i in 1:trials){
  PV_loss[i]=loss[i]/((1+IR)^10)
}


#calculate NPV
NPV <- rep(NA,trials)
for(i in 1:trials){
  NPV[i] <- -I[i] + accumPV_Net[i] - PV_loss[i]
}

mean(NPV)
sd(NPV)
hist(NPV)
boxplot(NPV)


data=data.frame(I,accumPV_Net,loss,i,NPV)

result=data.frame(matrix(data=c(mean(NPV),sd(NPV)),nrow=1,byrow = T))
result