library(TSA)
library(fUnitRoots)
data<-read.csv("/Users/nutchaj/Desktop/SAA/Data/data.csv",header=T,sep=",")

#create time series data
d_max<-data[,3]
t_max<-ts(d_max,freq=365.25,start=c(2002, 2,12))
plot(t_max,ylab='maximum eletronVolt',type='l')

d_max.training<-data[c(1:2283,2285:2286,2288:2349,2351:4346),3]
d_max.forecasting<-data[4347:4581,3]
t_max.training<-ts(d_max.training,freq=365.25,start=c(2002, 2,12))
plot(t_max.training,ylab='maximum eletronVolt',type='o')

#test for unit root 
adfTest(t_max.training,lags=1,type = c("nc"))    #smaller than 0.01 means stationary
###########model specification################################
acf(t_max.training)    
pacf(t_max.training)
x=eacf(t_max.training)
x$eacf ###suggest model ARMA(1,1)

res<-armasubsets(t_max.training,nar=8,nma=8,y.name='test',
                 ar.method='ols')
plot(res) ###suggest model ARMA(2,3) 

####model 1################################################# 
m1<-arima(t_max.training, order=c(1,0,1),method='ML') # maximum likelihood
m1 

#try overfitting with ARMA(1,2) and ARMA(2,1) -- ARMA(2,1) is proper
m1.1<-arima(t_max.training, order=c(2,0,1), method='ML') # maximum likelihood
m1.1 

m1.2<-arima(t_max.training, order=c(1,0,2),method='ML') # maximum likelihood
m1.2 

#selected model
m1<-arima(t_max.training, order=c(2,0,1),method='ML') # maximum likelihood

#Residual plots
plot(rstandard(m1),ylab='Standardized residuals',type='o') #standardized residuals
abline(h=0) # white noise

#Normality test
qqnorm(residuals(m1))
qqline(residuals(m1))
shapiro.test(residuals(m1)) #not normal

#Ljung-Box test
Box.test(residuals(m1),lag=1, type="Ljung-Box") #no correlation

#########try log transformation -- does not work
log.m1<-arima(log(t_max.training), order=c(2,0,1),method='ML') # maximum likelihood
#Residual plots
plot(rstandard(log.m1),ylab='Standardized residuals',type='o') #standardized residuals
abline(h=0)
#Normality test
qqnorm(residuals(log.m1))
qqline(residuals(log.m1))
shapiro.test(residuals(log.m1))
Box.test(residuals(log.m1),lag=1, type="Ljung-Box")


####model 2#################################################
m2<-arima(t_max.training, order=c(2,0,3),method='ML') # maximum likelihood
m2

#try overfitting with ARMA(1,3) and ARMA(2,2) -- ARMA(2,2) is better: smaller AIC
m2.1<-arima(t_max.training, order=c(1,0,3),method='ML') # maximum likelihood
m2.1

m2.2<-arima(t_max.training, order=c(2,0,2),method='ML') # maximum likelihood
m2.24

#selected model
m2<-arima(t_max.training, order=c(2,0,2),method='ML') # maximum likelihood
#Residual plots
plot(residuals(m2),ylab='Standardized residuals',type='o') #standardized residuals
abline(h=0) #white noise with couple outliers

#Normality test
qqnorm(residuals(m2))
qqline(residuals(m2))
shapiro.test(residuals(m2)) #not normal

#Ljung-Box test
Box.test(residuals(m2),lag=1, type="Ljung-Box") #no correlation

#########try log transformation - does not work
log.m2<-arima(log(t_max.training), order=c(2,0,2),method='ML') # maximum likelihood
#Residual plots
plot(rstandard(log.m2),ylab='Standardized residuals',type='o') #standardized residuals
abline(h=0)
#Normality test
qqnorm(residuals(log.m2))
qqline(residuals(log.m2))
shapiro.test(residuals(log.m2))
Box.test(residuals(log.m2),lag=10, type="Ljung-Box",fitdf=2)

##############recommended models#####################
m1<-arima(t_max.training, order=c(2,0,1),method='ML')
m2<-arima(t_max.training, order=c(2,0,2),method='ML')

#############model forecasting##########################
#predict 235 steps ahead
rate1<-predict(m1,n.ahead=235)
plot(m1,n.ahead=235,type='b', col="red",xlab='Time')

# Create lower and upper prediction interval bounds
lower<-rate1$pred-qnorm(0.975,0,1)*rate1$se
upper<-rate1$pred+qnorm(0.975,0,1)*rate1$se
data.frame(day=c(1:235),lower,upper)

rate2<-predict(m2,n.ahead=235)
plot(m2,n.ahead=235,type='b', col="red",xlab='Time')

# Create lower and upper prediction interval bounds
lower<-rate2$pred-qnorm(0.975,0,1)*rate2$se
upper<-rate2$pred+qnorm(0.975,0,1)*rate2$se
data.frame(day=c(1:235),lower,upper)

#############final model##########################
m1.MSE<- mean((d_max.forecasting-rate1$pred)^2)
m1.MSE
m1.PMAD<-sum(abs(d_max.forecasting-rate1$pred))/sum(abs(d_max.forecasting))
m1.PMAD

m2.MSE<- mean((d_max.forecasting-rate2$pred)^2)
m2.MSE
m2.PMAD<-sum(abs(d_max.forecasting-rate2$pred))/sum(abs(d_max.forecasting))
m2.PMAD

